summaryrefslogtreecommitdiffstats
path: root/kscd/kcompactdisc.h
diff options
context:
space:
mode:
Diffstat (limited to 'kscd/kcompactdisc.h')
-rw-r--r--kscd/kcompactdisc.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kscd/kcompactdisc.h b/kscd/kcompactdisc.h
index 5825126d..2e6830ca 100644
--- a/kscd/kcompactdisc.h
+++ b/kscd/kcompactdisc.h
@@ -1,5 +1,5 @@
/*
* KCompactDisc - A CD drive interface for the KDE Project.
*
* Copyright (c) 2005 Shaheedur R. Haque <srhaque@iee.org>
*
@@ -26,7 +26,7 @@
#include <tqvaluelist.h>
/**
* KCompactDisc - A CD drive interface for the KDE Project.
*
* The disc lifecycle is modelled by these signals:
*
@@ -43,7 +43,7 @@
* All times in this interface are in milliseconds. Valid track numbers are
* positive numbers; zero is not a valid track number.
*/
-class KCompactDisc :
+class TDECompactDisc :
public TQObject
{
Q_OBJECT
@@ -55,8 +55,8 @@ public:
Asynchronous // Block until cdrom and cddb infromation has been obtained
};
- KCompactDisc(InformationMode=Synchronous);
- virtual ~KCompactDisc();
+ TDECompactDisc(InformationMode=Synchronous);
+ virtual ~TDECompactDisc();
/**
* Open/close tray.
@@ -294,7 +294,7 @@ private:
unsigned m_previousTrack;
void checkDeviceStatus();
TQString discStatus(int status);
- class KCompactDiscPrivate *d;
+ class TDECompactDiscPrivate *d;
InformationMode m_infoMode;
private slots:
@@ -1,5 +1,5 @@
/*
- * KCompactDisc - A CD drive interface for the KDE Project.
+ * TDECompactDisc - A CD drive interface for the KDE Project.
*
* Copyright (c) 2005 Shaheedur R. Haque <srhaque@iee.org>
@@ -26,7 +26,7 @@
#include <tqvaluelist.h>
/**
- * KCompactDisc - A CD drive interface for the KDE Project.
+ * TDECompactDisc - A CD drive interface for the KDE Project.
*
* The disc lifecycle is modelled by these signals: